==> gatsby-transformer-json-1.0.0.tgz: package/gatsby-node.js <==
"use strict";

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _extends2 = require("babel-runtime/helpers/extends");

var _extends3 = _interopRequireDefault(_extends2);

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var onCreateNode = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(_ref2) {
    var node = _ref2.node,
        boundActionCreators = _ref2.boundActionCreators,
        loadNodeContent = _ref2.loadNodeContent;
    var createNode, createParentChildLink, content, parsedContent, JSONArray;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            createNode = boundActionCreators.createNode, createParentChildLink = boundActionCreators.createParentChildLink;

            // We only care about JSON content.

            if (!(node.internal.mediaType !== "application/json")) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            _context.next = 5;
            return loadNodeContent(node);

          case 5:
            content = _context.sent;
            parsedContent = JSON.parse(content);

            // TODO handle non-array data.

            if (_.isArray(parsedContent)) {
              JSONArray = parsedContent.map(function (obj, i) {
                var objStr = (0, _stringify2.default)(obj);
                var contentDigest = crypto.createHash("md5").update(objStr).digest("hex");

                return (0, _extends3.default)({}, obj, {
                  id: obj.id ? obj.id : node.id + " [" + i + "] >>> JSON",
                  children: [],
                  parent: node.id,
                  internal: {
                    contentDigest: contentDigest,
                    // TODO make choosing the "type" a lot smarter. This assumes
                    // the parent node is a file.
                    // PascalCase
                    type: _.upperFirst(_.camelCase(node.name + " Json"))
                  }
                });
              });


              _.each(JSONArray, function (j) {
                createNode(j);
                createParentChildLink({ parent: node, child: j });
              });
            }

            return _context.abrupt("return");

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function onCreateNode(_x) {
    return _ref.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Promise = require("bluebird");
var fs = require("fs");
var _ = require("lodash");
var crypto = require("crypto");

exports.onCreateNode = onCreateNode;

==> gatsby-transformer-json-1.0.5.tgz: package/gatsby-node.js <==
"use strict";

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _extends2 = require("babel-runtime/helpers/extends");

var _extends3 = _interopRequireDefault(_extends2);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var onCreateNode = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(_ref) {
    var node = _ref.node,
        boundActionCreators = _ref.boundActionCreators,
        loadNodeContent = _ref.loadNodeContent;
    var createNode, createParentChildLink, content, parsedContent, JSONArray;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            createNode = boundActionCreators.createNode, createParentChildLink = boundActionCreators.createParentChildLink;

            // We only care about JSON content.

            if (!(node.internal.mediaType !== `application/json`)) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            _context.next = 5;
            return loadNodeContent(node);

          case 5:
            content = _context.sent;
            parsedContent = JSON.parse(content);

            // TODO handle non-array data.

            if (_.isArray(parsedContent)) {
              JSONArray = parsedContent.map(function (obj, i) {
                var objStr = JSON.stringify(obj);
                var contentDigest = crypto.createHash(`md5`).update(objStr).digest(`hex`);

                return (0, _extends3.default)({}, obj, {
                  id: obj.id ? obj.id : `${node.id} [${i}] >>> JSON`,
                  children: [],
                  parent: node.id,
                  internal: {
                    contentDigest,
                    // TODO make choosing the "type" a lot smarter. This assumes
                    // the parent node is a file.
                    // PascalCase
                    type: _.upperFirst(_.camelCase(`${node.name} Json`))
                  }
                });
              });


              _.each(JSONArray, function (j) {
                createNode(j);
                createParentChildLink({ parent: node, child: j });
              });
            }

            return _context.abrupt("return");

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function onCreateNode(_x) {
    return _ref2.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Promise = require(`bluebird`);
var fs = require(`fs`);
var _ = require(`lodash`);
var crypto = require(`crypto`);

exports.onCreateNode = onCreateNode;
